(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
    typeof define === 'function' && define.amd ? define(['exports'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global["@svelte-plugins/tooltips"] = {}));
})(this, (function (exports) { 'use strict';

    function run(fn) {
        return fn();
    }
    function blank_object() {
        return Object.create(null);
    }
    function run_all(fns) {
        fns.forEach(run);
    }

    let current_component;
    function set_current_component(component) {
        current_component = component;
    }
    function get_current_component() {
        if (!current_component)
            throw new Error('Function called outside component initialization');
        return current_component;
    }
    function onMount(fn) {
        get_current_component().$$.on_mount.push(fn);
    }
    function onDestroy(fn) {
        get_current_component().$$.on_destroy.push(fn);
    }
    Promise.resolve();
    const ATTR_REGEX = /[&"]/g;
    const CONTENT_REGEX = /[&<]/g;
    /**
     * Note: this method is performance sensitive and has been optimized
     * https://github.com/sveltejs/svelte/pull/5701
     */
    function escape(value, is_attr = false) {
        const str = String(value);
        const pattern = is_attr ? ATTR_REGEX : CONTENT_REGEX;
        pattern.lastIndex = 0;
        let escaped = '';
        let last = 0;
        while (pattern.test(str)) {
            const i = pattern.lastIndex - 1;
            const ch = str[i];
            escaped += str.substring(last, i) + (ch === '&' ? '&amp;' : (ch === '"' ? '&quot;' : '&lt;'));
            last = i + 1;
        }
        return escaped + str.substring(last);
    }
    let on_destroy;
    function create_ssr_component(fn) {
        function $$render(result, props, bindings, slots, context) {
            const parent_component = current_component;
            const $$ = {
                on_destroy,
                context: new Map(context || (parent_component ? parent_component.$$.context : [])),
                // these will be immediately discarded
                on_mount: [],
                before_update: [],
                after_update: [],
                callbacks: blank_object()
            };
            set_current_component({ $$ });
            const html = fn(result, props, bindings, slots);
            set_current_component(parent_component);
            return html;
        }
        return {
            render: (props = {}, { $$slots = {}, context = new Map() } = {}) => {
                on_destroy = [];
                const result = { title: '', head: '', css: new Set() };
                const html = $$render(result, props, {}, $$slots, context);
                run_all(on_destroy);
                return {
                    html,
                    css: {
                        code: Array.from(result.css).map(css => css.code).join('\n'),
                        map: null // TODO
                    },
                    head: result.title + result.head
                };
            },
            $$render
        };
    }
    function add_attribute(name, value, boolean) {
        if (value == null || (boolean && !value))
            return '';
        const assignment = (boolean && value === true) ? '' : `="${escape(value, true)}"`;
        return ` ${name}${assignment}`;
    }

    const isInViewport = element => {
      const rect = element.getBoundingClientRect();
      return rect.top >= 0 && rect.left >= 0 && rect.bottom <= (window.innerHeight || document.documentElement.clientHeight) && rect.right <= (window.innerWidth || document.documentElement.clientWidth);
    };

    const inverse = {
      left: 'right',
      right: 'left',
      top: 'bottom',
      bottom: 'top'
    };

    /* src/tooltip.svelte generated by Svelte v3.49.0 */
    const css$1 = {
      code: ":root{--tooltip-background-color:rgba(0, 0, 0, 0.9);--tooltip-border-radius:4px;--tooltip-box-shadow:0 1px 20px rgba(0, 0, 0, 0.25);--tooltip-font-family:-apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen-Sans, Ubuntu, Cantarell,\n      'Helvetica Neue', sans-serif;--tooltip-font-size:14px;--tooltip-font-weight:500;--tooltip-line-height:1.25rem;--tooltip-color:#fff;--tooltip-offset-x:12px;--tooltip-offset-y:12px;--tooltip-padding:12px;--tooltip-z-index:100;--tooltip-arrow-size:10px}.tooltip-container.svelte-kya8h2{position:relative}.tooltip.svelte-kya8h2{background-color:var(--tooltip-background-color);box-shadow:var(--tooltip-box-shadow);border-radius:var(--tooltip-border-radius);color:var(--tooltip-color);opacity:0;font-family:var(--tooltip-font-family);font-size:var(--tooltip-font-size);font-style:normal;font-weight:var(--tooltip-font-weight);line-height:var(--tooltip-line-height);padding:var(--tooltip-padding);position:absolute;text-align:left;visibility:hidden;white-space:nowrap;z-index:var(--tooltip-z-index)}.tooltip.show.svelte-kya8h2{opacity:1;visibility:visible;white-space:normal}.tooltip.bottom.svelte-kya8h2:after,.tooltip.left.svelte-kya8h2:after,.tooltip.right.svelte-kya8h2:after,.tooltip.top.svelte-kya8h2:after{border:var(--tooltip-arrow-size) solid var(--tooltip-background-color);content:' ';position:absolute}.tooltip.arrowless.svelte-kya8h2:after{border:0 !important}.tooltip.bottom.svelte-kya8h2{bottom:0;left:50%;transform:translate(-50%, calc(100% + var(--tooltip-offset-y)))}.tooltip.bottom.svelte-kya8h2:after{border-color:transparent transparent var(--tooltip-background-color);left:50%;top:0;transform:translate(-50%, -99%)}.tooltip.top.svelte-kya8h2{left:50%;top:0;transform:translate(-50%, calc(-100% - var(--tooltip-offset-y)))}.tooltip.top.svelte-kya8h2:after{border-color:var(--tooltip-background-color) transparent transparent transparent;bottom:0;left:50%;transform:translate(-50%, 99%)}.tooltip.left.svelte-kya8h2{left:0;top:50%;transform:translate(calc(-100% - var(--tooltip-offset-x)), -50%)}.tooltip.left.svelte-kya8h2:after{border-color:transparent transparent transparent var(--tooltip-background-color);right:0;top:50%;transform:translate(99%, -50%)}.tooltip.right.svelte-kya8h2{right:0;top:50%;transform:translate(calc(100% + var(--tooltip-offset-x)), -50%)}.tooltip.right.svelte-kya8h2:after{border-color:transparent var(--tooltip-background-color) transparent transparent;left:0;top:50%;transform:translate(-99%, -50%)}.tooltip.animation-fade.svelte-kya8h2{opacity:0;transition:opacity 0.25s ease-in-out}.tooltip.animation-fade.show.svelte-kya8h2{opacity:1}.tooltip.top.animation-slide.svelte-kya8h2{margin-top:10px;opacity:0;transition:opacity 0.25s ease-in-out, margin 0.25s ease-in-out}.tooltip.top.animation-slide.show.svelte-kya8h2{margin-top:0;opacity:1}.tooltip.bottom.animation-slide.svelte-kya8h2{margin-bottom:20px;opacity:0;transition:opacity 0.25s ease-in-out, margin 0.25s ease-in-out}.tooltip.bottom.animation-slide.show.svelte-kya8h2{margin-bottom:0;opacity:1}.tooltip.right.animation-slide.svelte-kya8h2{margin-right:20px;opacity:0;transition:opacity 0.25s ease-in-out, margin 0.25s ease-in-out}.tooltip.right.animation-slide.show.svelte-kya8h2{margin-right:0;opacity:1}.tooltip.left.animation-slide.svelte-kya8h2{margin-left:20px;opacity:0;transition:opacity 0.25s ease-in-out, margin 0.25s ease-in-out}.tooltip.left.animation-slide.show.svelte-kya8h2{margin-left:0;opacity:1}.tooltip.left.animation-puff.svelte-kya8h2{filter:blur(2px);opacity:0;transform:translate(calc(-100% - var(--tooltip-offset-x)), -50%) scale(2, 2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out}.tooltip.left.animation-puff.show.svelte-kya8h2{filter:blur(0);opacity:1;transform:translate(calc(-100% - var(--tooltip-offset-x)), -50%) scale(1, 1)}.tooltip.right.animation-puff.svelte-kya8h2{filter:blur(2px);opacity:0;transform:translate(calc(100% + var(--tooltip-offset-x)), -50%) scale(2, 2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out}.tooltip.right.animation-puff.show.svelte-kya8h2{filter:blur(0);opacity:1;transform:translate(calc(100% + var(--tooltip-offset-x)), -50%) scale(1, 1)}.tooltip.top.animation-puff.svelte-kya8h2{filter:blur(2px);opacity:0;transform:translate(-50%, calc(-100% - var(--tooltip-offset-y))) scale(2, 2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out}.tooltip.top.animation-puff.show.svelte-kya8h2{filter:blur(0);opacity:1;transform:translate(-50%, calc(-100% - var(--tooltip-offset-y))) scale(1, 1)}.tooltip.bottom.animation-puff.svelte-kya8h2{filter:blur(2px);opacity:0;transform:translate(-50%, calc(100% + var(--tooltip-offset-y))) scale(2, 2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out}.tooltip.bottom.animation-puff.show.svelte-kya8h2{filter:blur(0);opacity:1;transform:translate(-50%, calc(100% + var(--tooltip-offset-y))) scale(1, 1)}.tooltip.left.animation-bounce.svelte-kya8h2{opacity:0;transform:translate(calc(-100% - var(--tooltip-offset-x)), -50%) scale(1.2, 1.2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3)}.tooltip.left.animation-bounce.show.svelte-kya8h2{opacity:1;transform:translate(calc(-100% - var(--tooltip-offset-x)), -50%) scale(1, 1)}.tooltip.right.animation-bounce.svelte-kya8h2{opacity:0;transform:translate(calc(100% + var(--tooltip-offset-x)), -50%) scale(1.2, 1.2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3)}.tooltip.right.animation-bounce.show.svelte-kya8h2{opacity:1;transform:translate(calc(100% + var(--tooltip-offset-x)), -50%) scale(1, 1)}.tooltip.top.animation-bounce.svelte-kya8h2{opacity:0;transform:translate(-50%, calc(-100% - var(--tooltip-offset-y))) scale(1.2, 1.2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3)}.tooltip.top.animation-bounce.show.svelte-kya8h2{opacity:1;transform:translate(-50%, calc(-100% - var(--tooltip-offset-y))) scale(1, 1)}.tooltip.bottom.animation-bounce.svelte-kya8h2{opacity:0;transform:translate(-50%, calc(100% + var(--tooltip-offset-y))) scale(1.2, 1.2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3)}.tooltip.bottom.animation-bounce.show.svelte-kya8h2{opacity:1;transform:translate(-50%, calc(100% + var(--tooltip-offset-y))) scale(1, 1)}",
      map: "{\"version\":3,\"file\":\"tooltip.svelte\",\"sources\":[\"tooltip.svelte\"],\"sourcesContent\":[\"<script>\\n  import { onMount, onDestroy } from 'svelte';\\n  import { formatVariableKey, getMinWidth, isInViewport } from './helpers';\\n  import { inverse } from './constants';\\n\\n  export let content = '';\\n  export let align = 'left';\\n  export let position = 'top';\\n  export let maxWidth = 200;\\n  export let style = null;\\n  export let theme = '';\\n  export let animation = '';\\n  export let arrow = true;\\n  export let autoPosition = false;\\n\\n  let containerRef = null;\\n  let tooltipRef = null;\\n  let minWidth = 0;\\n  let component = null;\\n  let initialPosition = position;\\n  let animationEffect = null;\\n  let show = false;\\n  let timer = null;\\n\\n  const onMouseEnter = () => {\\n    const delay = animation ? 200 : 0;\\n\\n    if (autoPosition && !isInViewport(tooltipRef)) {\\n      position = inverse[position];\\n    }\\n\\n    if (animation) {\\n      animationEffect = animation;\\n    }\\n\\n    timer = setTimeout(() => (show = true), delay);\\n  };\\n\\n  const onMouseLeave = () => {\\n    show = false;\\n    position = initialPosition;\\n    animationEffect = null;\\n\\n    if (timer) {\\n      clearTimeout(timer);\\n      timer = null;\\n    }\\n  };\\n\\n  onMount(() => {\\n    if (containerRef !== null) {\\n      containerRef.addEventListener('mouseenter', onMouseEnter);\\n      containerRef.addEventListener('mouseleave', onMouseLeave);\\n    }\\n\\n    if (tooltipRef !== null) {\\n      if (isComponent && !component) {\\n        component = new content.component({\\n          target: tooltipRef,\\n          props: content.props\\n        });\\n      }\\n\\n      minWidth = getMinWidth(tooltipRef, maxWidth);\\n\\n      if (style && typeof style === 'object') {\\n        for (let prop in style) {\\n          const key = formatVariableKey(prop);\\n          const value = style[prop];\\n\\n          tooltipRef.style.setProperty(`--tooltip-${key}`, value);\\n        }\\n      }\\n    }\\n  });\\n\\n  onDestroy(() => {\\n    if (component) {\\n      component.$destroy();\\n      component = null;\\n    }\\n\\n    if (containerRef !== null) {\\n      containerRef.removeEventListener('mouseenter', onMouseEnter);\\n      containerRef.removeEventListener('mouseleave', onMouseLeave);\\n    }\\n  });\\n\\n  $: isComponent = typeof content === 'object';\\n</script>\\n\\n<span bind:this={containerRef} class=\\\"tooltip-container\\\">\\n  <slot />\\n  <div\\n    bind:this={tooltipRef}\\n    class=\\\"tooltip animation-{animationEffect} {position} {theme}\\\"\\n    class:arrowless={!arrow}\\n    class:show\\n    style=\\\"min-width: {minWidth}px; max-width: {maxWidth}px; text-align: {align};\\\"\\n  >\\n    {#if !isComponent}\\n      {@html content}\\n    {/if}\\n  </div>\\n</span>\\n\\n<style>\\n  /*--------------------------*\\n   * Theme Variables\\n   *--------------------------*/\\n\\n  :root {\\n    --tooltip-background-color: rgba(0, 0, 0, 0.9);\\n    --tooltip-border-radius: 4px;\\n    --tooltip-box-shadow: 0 1px 20px rgba(0, 0, 0, 0.25);\\n    --tooltip-font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen-Sans, Ubuntu, Cantarell,\\n      'Helvetica Neue', sans-serif;\\n    --tooltip-font-size: 14px;\\n    --tooltip-font-weight: 500;\\n    --tooltip-line-height: 1.25rem;\\n    --tooltip-color: #fff;\\n    --tooltip-offset-x: 12px;\\n    --tooltip-offset-y: 12px;\\n    --tooltip-padding: 12px;\\n    --tooltip-z-index: 100;\\n    --tooltip-arrow-size: 10px;\\n  }\\n\\n  /*--------------------------*\\n   * Tooltip Styling\\n   *--------------------------*/\\n\\n  .tooltip-container {\\n    position: relative;\\n  }\\n\\n  .tooltip {\\n    background-color: var(--tooltip-background-color);\\n    box-shadow: var(--tooltip-box-shadow);\\n    border-radius: var(--tooltip-border-radius);\\n    color: var(--tooltip-color);\\n    opacity: 0;\\n    font-family: var(--tooltip-font-family);\\n    font-size: var(--tooltip-font-size);\\n    font-style: normal;\\n    font-weight: var(--tooltip-font-weight);\\n    line-height: var(--tooltip-line-height);\\n    padding: var(--tooltip-padding);\\n    position: absolute;\\n    text-align: left;\\n    visibility: hidden;\\n    white-space: nowrap;\\n    z-index: var(--tooltip-z-index);\\n  }\\n\\n  .tooltip.show {\\n    opacity: 1;\\n    visibility: visible;\\n    white-space: normal;\\n  }\\n\\n  .tooltip.bottom:after,\\n  .tooltip.left:after,\\n  .tooltip.right:after,\\n  .tooltip.top:after {\\n    border: var(--tooltip-arrow-size) solid var(--tooltip-background-color);\\n    content: ' ';\\n    position: absolute;\\n  }\\n\\n  .tooltip.arrowless:after {\\n    border: 0 !important;\\n  }\\n\\n  .tooltip.bottom {\\n    bottom: 0;\\n    left: 50%;\\n    transform: translate(-50%, calc(100% + var(--tooltip-offset-y)));\\n  }\\n\\n  .tooltip.bottom:after {\\n    border-color: transparent transparent var(--tooltip-background-color);\\n    left: 50%;\\n    top: 0;\\n    transform: translate(-50%, -99%);\\n  }\\n\\n  .tooltip.top {\\n    left: 50%;\\n    top: 0;\\n    transform: translate(-50%, calc(-100% - var(--tooltip-offset-y)));\\n  }\\n\\n  .tooltip.top:after {\\n    border-color: var(--tooltip-background-color) transparent transparent transparent;\\n    bottom: 0;\\n    left: 50%;\\n    transform: translate(-50%, 99%);\\n  }\\n\\n  .tooltip.left {\\n    left: 0;\\n    top: 50%;\\n    transform: translate(calc(-100% - var(--tooltip-offset-x)), -50%);\\n  }\\n\\n  .tooltip.left:after {\\n    border-color: transparent transparent transparent var(--tooltip-background-color);\\n    right: 0;\\n    top: 50%;\\n    transform: translate(99%, -50%);\\n  }\\n\\n  .tooltip.right {\\n    right: 0;\\n    top: 50%;\\n    transform: translate(calc(100% + var(--tooltip-offset-x)), -50%);\\n  }\\n\\n  .tooltip.right:after {\\n    border-color: transparent var(--tooltip-background-color) transparent transparent;\\n    left: 0;\\n    top: 50%;\\n    transform: translate(-99%, -50%);\\n  }\\n\\n  /*--------------------------*\\n   * CSS Animations\\n   *--------------------------*/\\n\\n  /* Fade */\\n\\n  .tooltip.animation-fade {\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.animation-fade.show {\\n    opacity: 1;\\n  }\\n\\n  /* Slide */\\n\\n  .tooltip.top.animation-slide {\\n    margin-top: 10px;\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out, margin 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.top.animation-slide.show {\\n    margin-top: 0;\\n    opacity: 1;\\n  }\\n\\n  .tooltip.bottom.animation-slide {\\n    margin-bottom: 20px;\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out, margin 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.bottom.animation-slide.show {\\n    margin-bottom: 0;\\n    opacity: 1;\\n  }\\n\\n  .tooltip.right.animation-slide {\\n    margin-right: 20px;\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out, margin 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.right.animation-slide.show {\\n    margin-right: 0;\\n    opacity: 1;\\n  }\\n\\n  .tooltip.left.animation-slide {\\n    margin-left: 20px;\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out, margin 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.left.animation-slide.show {\\n    margin-left: 0;\\n    opacity: 1;\\n  }\\n\\n  /* Puff */\\n\\n  .tooltip.left.animation-puff {\\n    filter: blur(2px);\\n    opacity: 0;\\n    transform: translate(calc(-100% - var(--tooltip-offset-x)), -50%) scale(2, 2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.left.animation-puff.show {\\n    filter: blur(0);\\n    opacity: 1;\\n    transform: translate(calc(-100% - var(--tooltip-offset-x)), -50%) scale(1, 1);\\n  }\\n\\n  .tooltip.right.animation-puff {\\n    filter: blur(2px);\\n    opacity: 0;\\n    transform: translate(calc(100% + var(--tooltip-offset-x)), -50%) scale(2, 2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.right.animation-puff.show {\\n    filter: blur(0);\\n    opacity: 1;\\n    transform: translate(calc(100% + var(--tooltip-offset-x)), -50%) scale(1, 1);\\n  }\\n\\n  .tooltip.top.animation-puff {\\n    filter: blur(2px);\\n    opacity: 0;\\n    transform: translate(-50%, calc(-100% - var(--tooltip-offset-y))) scale(2, 2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.top.animation-puff.show {\\n    filter: blur(0);\\n    opacity: 1;\\n    transform: translate(-50%, calc(-100% - var(--tooltip-offset-y))) scale(1, 1);\\n  }\\n\\n  .tooltip.bottom.animation-puff {\\n    filter: blur(2px);\\n    opacity: 0;\\n    transform: translate(-50%, calc(100% + var(--tooltip-offset-y))) scale(2, 2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.bottom.animation-puff.show {\\n    filter: blur(0);\\n    opacity: 1;\\n    transform: translate(-50%, calc(100% + var(--tooltip-offset-y))) scale(1, 1);\\n  }\\n\\n  /* Bounce */\\n\\n  .tooltip.left.animation-bounce {\\n    opacity: 0;\\n    transform: translate(calc(-100% - var(--tooltip-offset-x)), -50%) scale(1.2, 1.2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3);\\n  }\\n\\n  .tooltip.left.animation-bounce.show {\\n    opacity: 1;\\n    transform: translate(calc(-100% - var(--tooltip-offset-x)), -50%) scale(1, 1);\\n  }\\n\\n  .tooltip.right.animation-bounce {\\n    opacity: 0;\\n    transform: translate(calc(100% + var(--tooltip-offset-x)), -50%) scale(1.2, 1.2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3);\\n  }\\n\\n  .tooltip.right.animation-bounce.show {\\n    opacity: 1;\\n    transform: translate(calc(100% + var(--tooltip-offset-x)), -50%) scale(1, 1);\\n  }\\n\\n  .tooltip.top.animation-bounce {\\n    opacity: 0;\\n    transform: translate(-50%, calc(-100% - var(--tooltip-offset-y))) scale(1.2, 1.2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3);\\n  }\\n\\n  .tooltip.top.animation-bounce.show {\\n    opacity: 1;\\n    transform: translate(-50%, calc(-100% - var(--tooltip-offset-y))) scale(1, 1);\\n  }\\n\\n  .tooltip.bottom.animation-bounce {\\n    opacity: 0;\\n    transform: translate(-50%, calc(100% + var(--tooltip-offset-y))) scale(1.2, 1.2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3);\\n  }\\n\\n  .tooltip.bottom.animation-bounce.show {\\n    opacity: 1;\\n    transform: translate(-50%, calc(100% + var(--tooltip-offset-y))) scale(1, 1);\\n  }\\n</style>\\n\"],\"names\":[],\"mappings\":\"AA+GE,KAAK,AAAC,CAAC,AACL,0BAA0B,CAAE,kBAAkB,CAC9C,uBAAuB,CAAE,GAAG,CAC5B,oBAAoB,CAAE,8BAA8B,CACpD,qBAAqB,CAAE;kCACO,CAC9B,mBAAmB,CAAE,IAAI,CACzB,qBAAqB,CAAE,GAAG,CAC1B,qBAAqB,CAAE,OAAO,CAC9B,eAAe,CAAE,IAAI,CACrB,kBAAkB,CAAE,IAAI,CACxB,kBAAkB,CAAE,IAAI,CACxB,iBAAiB,CAAE,IAAI,CACvB,iBAAiB,CAAE,GAAG,CACtB,oBAAoB,CAAE,IAAI,AAC5B,CAAC,AAMD,kBAAkB,cAAC,CAAC,AAClB,QAAQ,CAAE,QAAQ,AACpB,CAAC,AAED,QAAQ,cAAC,CAAC,AACR,gBAAgB,CAAE,IAAI,0BAA0B,CAAC,CACjD,UAAU,CAAE,IAAI,oBAAoB,CAAC,CACrC,aAAa,CAAE,IAAI,uBAAuB,CAAC,CAC3C,KAAK,CAAE,IAAI,eAAe,CAAC,CAC3B,OAAO,CAAE,CAAC,CACV,WAAW,CAAE,IAAI,qBAAqB,CAAC,CACvC,SAAS,CAAE,IAAI,mBAAmB,CAAC,CACnC,UAAU,CAAE,MAAM,CAClB,WAAW,CAAE,IAAI,qBAAqB,CAAC,CACvC,WAAW,CAAE,IAAI,qBAAqB,CAAC,CACvC,OAAO,CAAE,IAAI,iBAAiB,CAAC,CAC/B,QAAQ,CAAE,QAAQ,CAClB,UAAU,CAAE,IAAI,CAChB,UAAU,CAAE,MAAM,CAClB,WAAW,CAAE,MAAM,CACnB,OAAO,CAAE,IAAI,iBAAiB,CAAC,AACjC,CAAC,AAED,QAAQ,KAAK,cAAC,CAAC,AACb,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CACnB,WAAW,CAAE,MAAM,AACrB,CAAC,AAED,QAAQ,qBAAO,MAAM,CACrB,QAAQ,mBAAK,MAAM,CACnB,QAAQ,oBAAM,MAAM,CACpB,QAAQ,kBAAI,MAAM,AAAC,CAAC,AAClB,MAAM,CAAE,IAAI,oBAAoB,CAAC,CAAC,KAAK,CAAC,IAAI,0BAA0B,CAAC,CACvE,OAAO,CAAE,GAAG,CACZ,QAAQ,CAAE,QAAQ,AACpB,CAAC,AAED,QAAQ,wBAAU,MAAM,AAAC,CAAC,AACxB,MAAM,CAAE,CAAC,CAAC,UAAU,AACtB,CAAC,AAED,QAAQ,OAAO,cAAC,CAAC,AACf,MAAM,CAAE,CAAC,CACT,IAAI,CAAE,GAAG,CACT,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,AAClE,CAAC,AAED,QAAQ,qBAAO,MAAM,AAAC,CAAC,AACrB,YAAY,CAAE,WAAW,CAAC,WAAW,CAAC,IAAI,0BAA0B,CAAC,CACrE,IAAI,CAAE,GAAG,CACT,GAAG,CAAE,CAAC,CACN,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,IAAI,CAAC,AAClC,CAAC,AAED,QAAQ,IAAI,cAAC,CAAC,AACZ,IAAI,CAAE,GAAG,CACT,GAAG,CAAE,CAAC,CACN,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,AACnE,CAAC,AAED,QAAQ,kBAAI,MAAM,AAAC,CAAC,AAClB,YAAY,CAAE,IAAI,0BAA0B,CAAC,CAAC,WAAW,CAAC,WAAW,CAAC,WAAW,CACjF,MAAM,CAAE,CAAC,CACT,IAAI,CAAE,GAAG,CACT,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,GAAG,CAAC,AACjC,CAAC,AAED,QAAQ,KAAK,cAAC,CAAC,AACb,IAAI,CAAE,CAAC,CACP,GAAG,CAAE,GAAG,CACR,SAAS,CAAE,UAAU,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,AACnE,CAAC,AAED,QAAQ,mBAAK,MAAM,AAAC,CAAC,AACnB,YAAY,CAAE,WAAW,CAAC,WAAW,CAAC,WAAW,CAAC,IAAI,0BAA0B,CAAC,CACjF,KAAK,CAAE,CAAC,CACR,GAAG,CAAE,GAAG,CACR,SAAS,CAAE,UAAU,GAAG,CAAC,CAAC,IAAI,CAAC,AACjC,CAAC,AAED,QAAQ,MAAM,cAAC,CAAC,AACd,KAAK,CAAE,CAAC,CACR,GAAG,CAAE,GAAG,CACR,SAAS,CAAE,UAAU,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,AAClE,CAAC,AAED,QAAQ,oBAAM,MAAM,AAAC,CAAC,AACpB,YAAY,CAAE,WAAW,CAAC,IAAI,0BAA0B,CAAC,CAAC,WAAW,CAAC,WAAW,CACjF,IAAI,CAAE,CAAC,CACP,GAAG,CAAE,GAAG,CACR,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,IAAI,CAAC,AAClC,CAAC,AAQD,QAAQ,eAAe,cAAC,CAAC,AACvB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,AACvC,CAAC,AAED,QAAQ,eAAe,KAAK,cAAC,CAAC,AAC5B,OAAO,CAAE,CAAC,AACZ,CAAC,AAID,QAAQ,IAAI,gBAAgB,cAAC,CAAC,AAC5B,UAAU,CAAE,IAAI,CAChB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,AACjE,CAAC,AAED,QAAQ,IAAI,gBAAgB,KAAK,cAAC,CAAC,AACjC,UAAU,CAAE,CAAC,CACb,OAAO,CAAE,CAAC,AACZ,CAAC,AAED,QAAQ,OAAO,gBAAgB,cAAC,CAAC,AAC/B,aAAa,CAAE,IAAI,CACnB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,AACjE,CAAC,AAED,QAAQ,OAAO,gBAAgB,KAAK,cAAC,CAAC,AACpC,aAAa,CAAE,CAAC,CAChB,OAAO,CAAE,CAAC,AACZ,CAAC,AAED,QAAQ,MAAM,gBAAgB,cAAC,CAAC,AAC9B,YAAY,CAAE,IAAI,CAClB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,AACjE,CAAC,AAED,QAAQ,MAAM,gBAAgB,KAAK,cAAC,CAAC,AACnC,YAAY,CAAE,CAAC,CACf,OAAO,CAAE,CAAC,AACZ,CAAC,AAED,QAAQ,KAAK,gBAAgB,cAAC,CAAC,AAC7B,WAAW,CAAE,IAAI,CACjB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,AACjE,CAAC,AAED,QAAQ,KAAK,gBAAgB,KAAK,cAAC,CAAC,AAClC,WAAW,CAAE,CAAC,CACd,OAAO,CAAE,CAAC,AACZ,CAAC,AAID,QAAQ,KAAK,eAAe,cAAC,CAAC,AAC5B,MAAM,CAAE,KAAK,GAAG,CAAC,CACjB,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,CAC7E,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,WAAW,AAC9F,CAAC,AAED,QAAQ,KAAK,eAAe,KAAK,cAAC,CAAC,AACjC,MAAM,CAAE,KAAK,CAAC,CAAC,CACf,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,AAC/E,CAAC,AAED,QAAQ,MAAM,eAAe,cAAC,CAAC,AAC7B,MAAM,CAAE,KAAK,GAAG,CAAC,CACjB,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,CAC5E,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,WAAW,AAC9F,CAAC,AAED,QAAQ,MAAM,eAAe,KAAK,cAAC,CAAC,AAClC,MAAM,CAAE,KAAK,CAAC,CAAC,CACf,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,AAC9E,CAAC,AAED,QAAQ,IAAI,eAAe,cAAC,CAAC,AAC3B,MAAM,CAAE,KAAK,GAAG,CAAC,CACjB,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,CAC7E,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,WAAW,AAC9F,CAAC,AAED,QAAQ,IAAI,eAAe,KAAK,cAAC,CAAC,AAChC,MAAM,CAAE,KAAK,CAAC,CAAC,CACf,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,AAC/E,CAAC,AAED,QAAQ,OAAO,eAAe,cAAC,CAAC,AAC9B,MAAM,CAAE,KAAK,GAAG,CAAC,CACjB,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,CAC5E,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,WAAW,AAC9F,CAAC,AAED,QAAQ,OAAO,eAAe,KAAK,cAAC,CAAC,AACnC,MAAM,CAAE,KAAK,CAAC,CAAC,CACf,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,AAC9E,CAAC,AAID,QAAQ,KAAK,iBAAiB,cAAC,CAAC,AAC9B,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,CAAC,MAAM,GAAG,CAAC,CAAC,GAAG,CAAC,CACjF,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,aAAa,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CAAC,AACtF,CAAC,AAED,QAAQ,KAAK,iBAAiB,KAAK,cAAC,CAAC,AACnC,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,AAC/E,CAAC,AAED,QAAQ,MAAM,iBAAiB,cAAC,CAAC,AAC/B,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,CAAC,MAAM,GAAG,CAAC,CAAC,GAAG,CAAC,CAChF,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,aAAa,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CAAC,AACtF,CAAC,AAED,QAAQ,MAAM,iBAAiB,KAAK,cAAC,CAAC,AACpC,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,AAC9E,CAAC,AAED,QAAQ,IAAI,iBAAiB,cAAC,CAAC,AAC7B,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,MAAM,GAAG,CAAC,CAAC,GAAG,CAAC,CACjF,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,aAAa,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CAAC,AACtF,CAAC,AAED,QAAQ,IAAI,iBAAiB,KAAK,cAAC,CAAC,AAClC,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,AAC/E,CAAC,AAED,QAAQ,OAAO,iBAAiB,cAAC,CAAC,AAChC,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,MAAM,GAAG,CAAC,CAAC,GAAG,CAAC,CAChF,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,aAAa,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CAAC,AACtF,CAAC,AAED,QAAQ,OAAO,iBAAiB,KAAK,cAAC,CAAC,AACrC,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,AAC9E,CAAC\"}"
    };
    const Tooltip$1 = create_ssr_component(($$result, $$props, $$bindings, slots) => {
      let isComponent;
      let {
        content = ''
      } = $$props;
      let {
        align = 'left'
      } = $$props;
      let {
        position = 'top'
      } = $$props;
      let {
        maxWidth = 200
      } = $$props;
      let {
        style = null
      } = $$props;
      let {
        theme = ''
      } = $$props;
      let {
        animation = ''
      } = $$props;
      let {
        arrow = true
      } = $$props;
      let {
        autoPosition = false
      } = $$props;
      let containerRef = null;
      let tooltipRef = null;
      let minWidth = 0;
      let animationEffect = null;

      onMount(() => {
      });
      onDestroy(() => {
      });
      if ($$props.content === void 0 && $$bindings.content && content !== void 0) $$bindings.content(content);
      if ($$props.align === void 0 && $$bindings.align && align !== void 0) $$bindings.align(align);
      if ($$props.position === void 0 && $$bindings.position && position !== void 0) $$bindings.position(position);
      if ($$props.maxWidth === void 0 && $$bindings.maxWidth && maxWidth !== void 0) $$bindings.maxWidth(maxWidth);
      if ($$props.style === void 0 && $$bindings.style && style !== void 0) $$bindings.style(style);
      if ($$props.theme === void 0 && $$bindings.theme && theme !== void 0) $$bindings.theme(theme);
      if ($$props.animation === void 0 && $$bindings.animation && animation !== void 0) $$bindings.animation(animation);
      if ($$props.arrow === void 0 && $$bindings.arrow && arrow !== void 0) $$bindings.arrow(arrow);
      if ($$props.autoPosition === void 0 && $$bindings.autoPosition && autoPosition !== void 0) $$bindings.autoPosition(autoPosition);
      $$result.css.add(css$1);
      isComponent = typeof content === 'object';
      return "<span class=\"".concat("tooltip-container svelte-kya8h2", "\"", add_attribute("this", containerRef, 0), ">").concat(slots.default ? slots.default({}) : "", "\n  <div class=\"").concat(["tooltip animation-" + escape(animationEffect, true) + " " + escape(position, true) + " " + escape(theme, true) + " svelte-kya8h2", (!arrow ? "arrowless" : "") + ' ' + ("")].join(' ').trim(), "\" style=\"").concat("min-width: " + escape(minWidth, true) + "px; max-width: " + escape(maxWidth, true) + "px; text-align: " + escape(align, true) + ";", "\"").concat(add_attribute("this", tooltipRef, 0), ">").concat(!isComponent ? "".concat(content) : "", "</div>\n</span>");
    });
    var Tooltip$2 = Tooltip$1;

    /* src/action-tooltip.svelte generated by Svelte v3.49.0 */
    const css = {
      code: ":root{--tooltip-background-color:rgba(0, 0, 0, 0.9);--tooltip-border-radius:4px;--tooltip-box-shadow:0 1px 20px rgba(0, 0, 0, 0.25);--tooltip-font-family:-apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen-Sans, Ubuntu, Cantarell,\n      'Helvetica Neue', sans-serif;--tooltip-font-size:14px;--tooltip-font-weight:500;--tooltip-line-height:1.25rem;--tooltip-color:#fff;--tooltip-offset-x:12px;--tooltip-offset-y:12px;--tooltip-padding:12px;--tooltip-z-index:100;--tooltip-arrow-size:10px}.tooltip.svelte-oe317f{background-color:var(--tooltip-background-color);box-shadow:var(--tooltip-box-shadow);border-radius:var(--tooltip-border-radius);color:var(--tooltip-color);opacity:0;font-family:var(--tooltip-font-family);font-size:var(--tooltip-font-size);font-style:normal;font-weight:var(--tooltip-font-weight);line-height:var(--tooltip-line-height);padding:var(--tooltip-padding);position:absolute;text-align:left;visibility:hidden;white-space:nowrap;z-index:var(--tooltip-z-index)}.tooltip.show.svelte-oe317f{opacity:1;visibility:visible;white-space:normal}.tooltip.bottom.svelte-oe317f:after,.tooltip.left.svelte-oe317f:after,.tooltip.right.svelte-oe317f:after,.tooltip.top.svelte-oe317f:after{border:var(--tooltip-arrow-size) solid var(--tooltip-background-color);content:' ';position:absolute}.tooltip.arrowless.svelte-oe317f:after{border:0 !important}.tooltip.bottom.svelte-oe317f{bottom:0;left:50%;transform:translate(-50%, calc(100% + var(--tooltip-offset-y)))}.tooltip.bottom.svelte-oe317f:after{border-color:transparent transparent var(--tooltip-background-color);left:50%;top:0;transform:translate(-50%, -99%)}.tooltip.top.svelte-oe317f{left:50%;top:0;transform:translate(-50%, calc(-100% - var(--tooltip-offset-y)))}.tooltip.top.svelte-oe317f:after{border-color:var(--tooltip-background-color) transparent transparent transparent;bottom:0;left:50%;transform:translate(-50%, 99%)}.tooltip.left.svelte-oe317f{left:0;top:50%;transform:translate(calc(-100% - var(--tooltip-offset-x)), -50%)}.tooltip.left.svelte-oe317f:after{border-color:transparent transparent transparent var(--tooltip-background-color);right:0;top:50%;transform:translate(99%, -50%)}.tooltip.right.svelte-oe317f{right:0;top:50%;transform:translate(calc(100% + var(--tooltip-offset-x)), -50%)}.tooltip.right.svelte-oe317f:after{border-color:transparent var(--tooltip-background-color) transparent transparent;left:0;top:50%;transform:translate(-99%, -50%)}.tooltip.animation-fade.svelte-oe317f{opacity:0;transition:opacity 0.25s ease-in-out}.tooltip.animation-fade.show.svelte-oe317f{opacity:1}.tooltip.top.animation-slide.svelte-oe317f{margin-top:10px;opacity:0;transition:opacity 0.25s ease-in-out, margin 0.25s ease-in-out}.tooltip.top.animation-slide.show.svelte-oe317f{margin-top:0;opacity:1}.tooltip.bottom.animation-slide.svelte-oe317f{margin-bottom:20px;opacity:0;transition:opacity 0.25s ease-in-out, margin 0.25s ease-in-out}.tooltip.bottom.animation-slide.show.svelte-oe317f{margin-bottom:0;opacity:1}.tooltip.right.animation-slide.svelte-oe317f{margin-right:20px;opacity:0;transition:opacity 0.25s ease-in-out, margin 0.25s ease-in-out}.tooltip.right.animation-slide.show.svelte-oe317f{margin-right:0;opacity:1}.tooltip.left.animation-slide.svelte-oe317f{margin-left:20px;opacity:0;transition:opacity 0.25s ease-in-out, margin 0.25s ease-in-out}.tooltip.left.animation-slide.show.svelte-oe317f{margin-left:0;opacity:1}.tooltip.left.animation-puff.svelte-oe317f{filter:blur(2px);opacity:0;transform:translate(calc(-100% - var(--tooltip-offset-x)), -50%) scale(2, 2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out}.tooltip.left.animation-puff.show.svelte-oe317f{filter:blur(0);opacity:1;transform:translate(calc(-100% - var(--tooltip-offset-x)), -50%) scale(1, 1)}.tooltip.right.animation-puff.svelte-oe317f{filter:blur(2px);opacity:0;transform:translate(calc(100% + var(--tooltip-offset-x)), -50%) scale(2, 2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out}.tooltip.right.animation-puff.show.svelte-oe317f{filter:blur(0);opacity:1;transform:translate(calc(100% + var(--tooltip-offset-x)), -50%) scale(1, 1)}.tooltip.top.animation-puff.svelte-oe317f{filter:blur(2px);opacity:0;transform:translate(-50%, calc(-100% - var(--tooltip-offset-y))) scale(2, 2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out}.tooltip.top.animation-puff.show.svelte-oe317f{filter:blur(0);opacity:1;transform:translate(-50%, calc(-100% - var(--tooltip-offset-y))) scale(1, 1)}.tooltip.bottom.animation-puff.svelte-oe317f{filter:blur(2px);opacity:0;transform:translate(-50%, calc(100% + var(--tooltip-offset-y))) scale(2, 2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out}.tooltip.bottom.animation-puff.show.svelte-oe317f{filter:blur(0);opacity:1;transform:translate(-50%, calc(100% + var(--tooltip-offset-y))) scale(1, 1)}.tooltip.left.animation-bounce.svelte-oe317f{opacity:0;transform:translate(calc(-100% - var(--tooltip-offset-x)), -50%) scale(1.2, 1.2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3)}.tooltip.left.animation-bounce.show.svelte-oe317f{opacity:1;transform:translate(calc(-100% - var(--tooltip-offset-x)), -50%) scale(1, 1)}.tooltip.right.animation-bounce.svelte-oe317f{opacity:0;transform:translate(calc(100% + var(--tooltip-offset-x)), -50%) scale(1.2, 1.2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3)}.tooltip.right.animation-bounce.show.svelte-oe317f{opacity:1;transform:translate(calc(100% + var(--tooltip-offset-x)), -50%) scale(1, 1)}.tooltip.top.animation-bounce.svelte-oe317f{opacity:0;transform:translate(-50%, calc(-100% - var(--tooltip-offset-y))) scale(1.2, 1.2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3)}.tooltip.top.animation-bounce.show.svelte-oe317f{opacity:1;transform:translate(-50%, calc(-100% - var(--tooltip-offset-y))) scale(1, 1)}.tooltip.bottom.animation-bounce.svelte-oe317f{opacity:0;transform:translate(-50%, calc(100% + var(--tooltip-offset-y))) scale(1.2, 1.2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3)}.tooltip.bottom.animation-bounce.show.svelte-oe317f{opacity:1;transform:translate(-50%, calc(100% + var(--tooltip-offset-y))) scale(1, 1)}",
      map: "{\"version\":3,\"file\":\"action-tooltip.svelte\",\"sources\":[\"action-tooltip.svelte\"],\"sourcesContent\":[\"<script>\\n  import { onMount, onDestroy } from 'svelte';\\n  import { formatVariableKey, getMinWidth, isInViewport } from './helpers';\\n  import { inverse } from './constants';\\n\\n  export let content = '';\\n  export let align = 'left';\\n  export let position = 'top';\\n  export let maxWidth = 200;\\n  export let style = null;\\n  export let theme = '';\\n  export let animation = '';\\n  export let arrow = true;\\n  export let autoPosition = false;\\n\\n  let ref = null;\\n  let minWidth = 0;\\n  let component = null;\\n  let animationEffect = null;\\n  let show = false;\\n\\n  onMount(() => {\\n    const delay = animation ? 200 : 0;\\n\\n    if (ref !== null) {\\n      if (isComponent && !component) {\\n        component = new content.component({ target: ref, props: content.props });\\n      }\\n\\n      minWidth = getMinWidth(ref, maxWidth);\\n\\n      if (style && typeof style === 'object') {\\n        for (let prop in style) {\\n          const key = formatVariableKey(prop);\\n          const value = style[prop];\\n\\n          ref.style.setProperty(`--tooltip-${key}`, value);\\n        }\\n      }\\n    }\\n\\n    if (autoPosition && !isInViewport(ref)) {\\n      position = inverse[position];\\n    }\\n\\n    if (animation) {\\n      animationEffect = animation;\\n    }\\n\\n    setTimeout(() => (show = true), delay);\\n  });\\n\\n  onDestroy(() => {\\n    if (component) {\\n      component.$destroy();\\n      component = null;\\n    }\\n  });\\n\\n  $: isComponent = typeof content === 'object';\\n</script>\\n\\n<div\\n  bind:this={ref}\\n  class=\\\"tooltip animation-{animationEffect} {position} {theme}\\\"\\n  class:show\\n  class:arrowless={!arrow}\\n  style=\\\"min-width: {minWidth}px; max-width: {maxWidth}px; text-align: {align};\\\"\\n>\\n  {#if !isComponent}\\n    {@html content}\\n  {/if}\\n</div>\\n\\n<style>\\n  /*--------------------------*\\n   * Theme Variables\\n   *--------------------------*/\\n\\n  :root {\\n    --tooltip-background-color: rgba(0, 0, 0, 0.9);\\n    --tooltip-border-radius: 4px;\\n    --tooltip-box-shadow: 0 1px 20px rgba(0, 0, 0, 0.25);\\n    --tooltip-font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen-Sans, Ubuntu, Cantarell,\\n      'Helvetica Neue', sans-serif;\\n    --tooltip-font-size: 14px;\\n    --tooltip-font-weight: 500;\\n    --tooltip-line-height: 1.25rem;\\n    --tooltip-color: #fff;\\n    --tooltip-offset-x: 12px;\\n    --tooltip-offset-y: 12px;\\n    --tooltip-padding: 12px;\\n    --tooltip-z-index: 100;\\n    --tooltip-arrow-size: 10px;\\n  }\\n\\n  /*--------------------------*\\n   * Tooltip Styling\\n   *--------------------------*/\\n\\n  .tooltip {\\n    background-color: var(--tooltip-background-color);\\n    box-shadow: var(--tooltip-box-shadow);\\n    border-radius: var(--tooltip-border-radius);\\n    color: var(--tooltip-color);\\n    opacity: 0;\\n    font-family: var(--tooltip-font-family);\\n    font-size: var(--tooltip-font-size);\\n    font-style: normal;\\n    font-weight: var(--tooltip-font-weight);\\n    line-height: var(--tooltip-line-height);\\n    padding: var(--tooltip-padding);\\n    position: absolute;\\n    text-align: left;\\n    visibility: hidden;\\n    white-space: nowrap;\\n    z-index: var(--tooltip-z-index);\\n  }\\n\\n  .tooltip.show {\\n    opacity: 1;\\n    visibility: visible;\\n    white-space: normal;\\n  }\\n\\n  .tooltip.bottom:after,\\n  .tooltip.left:after,\\n  .tooltip.right:after,\\n  .tooltip.top:after {\\n    border: var(--tooltip-arrow-size) solid var(--tooltip-background-color);\\n    content: ' ';\\n    position: absolute;\\n  }\\n\\n  .tooltip.arrowless:after {\\n    border: 0 !important;\\n  }\\n\\n  .tooltip.bottom {\\n    bottom: 0;\\n    left: 50%;\\n    transform: translate(-50%, calc(100% + var(--tooltip-offset-y)));\\n  }\\n\\n  .tooltip.bottom:after {\\n    border-color: transparent transparent var(--tooltip-background-color);\\n    left: 50%;\\n    top: 0;\\n    transform: translate(-50%, -99%);\\n  }\\n\\n  .tooltip.top {\\n    left: 50%;\\n    top: 0;\\n    transform: translate(-50%, calc(-100% - var(--tooltip-offset-y)));\\n  }\\n\\n  .tooltip.top:after {\\n    border-color: var(--tooltip-background-color) transparent transparent transparent;\\n    bottom: 0;\\n    left: 50%;\\n    transform: translate(-50%, 99%);\\n  }\\n\\n  .tooltip.left {\\n    left: 0;\\n    top: 50%;\\n    transform: translate(calc(-100% - var(--tooltip-offset-x)), -50%);\\n  }\\n\\n  .tooltip.left:after {\\n    border-color: transparent transparent transparent var(--tooltip-background-color);\\n    right: 0;\\n    top: 50%;\\n    transform: translate(99%, -50%);\\n  }\\n\\n  .tooltip.right {\\n    right: 0;\\n    top: 50%;\\n    transform: translate(calc(100% + var(--tooltip-offset-x)), -50%);\\n  }\\n\\n  .tooltip.right:after {\\n    border-color: transparent var(--tooltip-background-color) transparent transparent;\\n    left: 0;\\n    top: 50%;\\n    transform: translate(-99%, -50%);\\n  }\\n\\n  /*--------------------------*\\n   * CSS Animations\\n   *--------------------------*/\\n\\n  /* Fade */\\n\\n  .tooltip.animation-fade {\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.animation-fade.show {\\n    opacity: 1;\\n  }\\n\\n  /* Slide */\\n\\n  .tooltip.top.animation-slide {\\n    margin-top: 10px;\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out, margin 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.top.animation-slide.show {\\n    margin-top: 0;\\n    opacity: 1;\\n  }\\n\\n  .tooltip.bottom.animation-slide {\\n    margin-bottom: 20px;\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out, margin 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.bottom.animation-slide.show {\\n    margin-bottom: 0;\\n    opacity: 1;\\n  }\\n\\n  .tooltip.right.animation-slide {\\n    margin-right: 20px;\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out, margin 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.right.animation-slide.show {\\n    margin-right: 0;\\n    opacity: 1;\\n  }\\n\\n  .tooltip.left.animation-slide {\\n    margin-left: 20px;\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out, margin 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.left.animation-slide.show {\\n    margin-left: 0;\\n    opacity: 1;\\n  }\\n\\n  /* Puff */\\n\\n  .tooltip.left.animation-puff {\\n    filter: blur(2px);\\n    opacity: 0;\\n    transform: translate(calc(-100% - var(--tooltip-offset-x)), -50%) scale(2, 2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.left.animation-puff.show {\\n    filter: blur(0);\\n    opacity: 1;\\n    transform: translate(calc(-100% - var(--tooltip-offset-x)), -50%) scale(1, 1);\\n  }\\n\\n  .tooltip.right.animation-puff {\\n    filter: blur(2px);\\n    opacity: 0;\\n    transform: translate(calc(100% + var(--tooltip-offset-x)), -50%) scale(2, 2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.right.animation-puff.show {\\n    filter: blur(0);\\n    opacity: 1;\\n    transform: translate(calc(100% + var(--tooltip-offset-x)), -50%) scale(1, 1);\\n  }\\n\\n  .tooltip.top.animation-puff {\\n    filter: blur(2px);\\n    opacity: 0;\\n    transform: translate(-50%, calc(-100% - var(--tooltip-offset-y))) scale(2, 2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.top.animation-puff.show {\\n    filter: blur(0);\\n    opacity: 1;\\n    transform: translate(-50%, calc(-100% - var(--tooltip-offset-y))) scale(1, 1);\\n  }\\n\\n  .tooltip.bottom.animation-puff {\\n    filter: blur(2px);\\n    opacity: 0;\\n    transform: translate(-50%, calc(100% + var(--tooltip-offset-y))) scale(2, 2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.bottom.animation-puff.show {\\n    filter: blur(0);\\n    opacity: 1;\\n    transform: translate(-50%, calc(100% + var(--tooltip-offset-y))) scale(1, 1);\\n  }\\n\\n  /* Bounce */\\n\\n  .tooltip.left.animation-bounce {\\n    opacity: 0;\\n    transform: translate(calc(-100% - var(--tooltip-offset-x)), -50%) scale(1.2, 1.2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3);\\n  }\\n\\n  .tooltip.left.animation-bounce.show {\\n    opacity: 1;\\n    transform: translate(calc(-100% - var(--tooltip-offset-x)), -50%) scale(1, 1);\\n  }\\n\\n  .tooltip.right.animation-bounce {\\n    opacity: 0;\\n    transform: translate(calc(100% + var(--tooltip-offset-x)), -50%) scale(1.2, 1.2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3);\\n  }\\n\\n  .tooltip.right.animation-bounce.show {\\n    opacity: 1;\\n    transform: translate(calc(100% + var(--tooltip-offset-x)), -50%) scale(1, 1);\\n  }\\n\\n  .tooltip.top.animation-bounce {\\n    opacity: 0;\\n    transform: translate(-50%, calc(-100% - var(--tooltip-offset-y))) scale(1.2, 1.2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3);\\n  }\\n\\n  .tooltip.top.animation-bounce.show {\\n    opacity: 1;\\n    transform: translate(-50%, calc(-100% - var(--tooltip-offset-y))) scale(1, 1);\\n  }\\n\\n  .tooltip.bottom.animation-bounce {\\n    opacity: 0;\\n    transform: translate(-50%, calc(100% + var(--tooltip-offset-y))) scale(1.2, 1.2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3);\\n  }\\n\\n  .tooltip.bottom.animation-bounce.show {\\n    opacity: 1;\\n    transform: translate(-50%, calc(100% + var(--tooltip-offset-y))) scale(1, 1);\\n  }\\n</style>\\n\"],\"names\":[],\"mappings\":\"AA+EE,KAAK,AAAC,CAAC,AACL,0BAA0B,CAAE,kBAAkB,CAC9C,uBAAuB,CAAE,GAAG,CAC5B,oBAAoB,CAAE,8BAA8B,CACpD,qBAAqB,CAAE;kCACO,CAC9B,mBAAmB,CAAE,IAAI,CACzB,qBAAqB,CAAE,GAAG,CAC1B,qBAAqB,CAAE,OAAO,CAC9B,eAAe,CAAE,IAAI,CACrB,kBAAkB,CAAE,IAAI,CACxB,kBAAkB,CAAE,IAAI,CACxB,iBAAiB,CAAE,IAAI,CACvB,iBAAiB,CAAE,GAAG,CACtB,oBAAoB,CAAE,IAAI,AAC5B,CAAC,AAMD,QAAQ,cAAC,CAAC,AACR,gBAAgB,CAAE,IAAI,0BAA0B,CAAC,CACjD,UAAU,CAAE,IAAI,oBAAoB,CAAC,CACrC,aAAa,CAAE,IAAI,uBAAuB,CAAC,CAC3C,KAAK,CAAE,IAAI,eAAe,CAAC,CAC3B,OAAO,CAAE,CAAC,CACV,WAAW,CAAE,IAAI,qBAAqB,CAAC,CACvC,SAAS,CAAE,IAAI,mBAAmB,CAAC,CACnC,UAAU,CAAE,MAAM,CAClB,WAAW,CAAE,IAAI,qBAAqB,CAAC,CACvC,WAAW,CAAE,IAAI,qBAAqB,CAAC,CACvC,OAAO,CAAE,IAAI,iBAAiB,CAAC,CAC/B,QAAQ,CAAE,QAAQ,CAClB,UAAU,CAAE,IAAI,CAChB,UAAU,CAAE,MAAM,CAClB,WAAW,CAAE,MAAM,CACnB,OAAO,CAAE,IAAI,iBAAiB,CAAC,AACjC,CAAC,AAED,QAAQ,KAAK,cAAC,CAAC,AACb,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CACnB,WAAW,CAAE,MAAM,AACrB,CAAC,AAED,QAAQ,qBAAO,MAAM,CACrB,QAAQ,mBAAK,MAAM,CACnB,QAAQ,oBAAM,MAAM,CACpB,QAAQ,kBAAI,MAAM,AAAC,CAAC,AAClB,MAAM,CAAE,IAAI,oBAAoB,CAAC,CAAC,KAAK,CAAC,IAAI,0BAA0B,CAAC,CACvE,OAAO,CAAE,GAAG,CACZ,QAAQ,CAAE,QAAQ,AACpB,CAAC,AAED,QAAQ,wBAAU,MAAM,AAAC,CAAC,AACxB,MAAM,CAAE,CAAC,CAAC,UAAU,AACtB,CAAC,AAED,QAAQ,OAAO,cAAC,CAAC,AACf,MAAM,CAAE,CAAC,CACT,IAAI,CAAE,GAAG,CACT,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,AAClE,CAAC,AAED,QAAQ,qBAAO,MAAM,AAAC,CAAC,AACrB,YAAY,CAAE,WAAW,CAAC,WAAW,CAAC,IAAI,0BAA0B,CAAC,CACrE,IAAI,CAAE,GAAG,CACT,GAAG,CAAE,CAAC,CACN,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,IAAI,CAAC,AAClC,CAAC,AAED,QAAQ,IAAI,cAAC,CAAC,AACZ,IAAI,CAAE,GAAG,CACT,GAAG,CAAE,CAAC,CACN,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,AACnE,CAAC,AAED,QAAQ,kBAAI,MAAM,AAAC,CAAC,AAClB,YAAY,CAAE,IAAI,0BAA0B,CAAC,CAAC,WAAW,CAAC,WAAW,CAAC,WAAW,CACjF,MAAM,CAAE,CAAC,CACT,IAAI,CAAE,GAAG,CACT,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,GAAG,CAAC,AACjC,CAAC,AAED,QAAQ,KAAK,cAAC,CAAC,AACb,IAAI,CAAE,CAAC,CACP,GAAG,CAAE,GAAG,CACR,SAAS,CAAE,UAAU,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,AACnE,CAAC,AAED,QAAQ,mBAAK,MAAM,AAAC,CAAC,AACnB,YAAY,CAAE,WAAW,CAAC,WAAW,CAAC,WAAW,CAAC,IAAI,0BAA0B,CAAC,CACjF,KAAK,CAAE,CAAC,CACR,GAAG,CAAE,GAAG,CACR,SAAS,CAAE,UAAU,GAAG,CAAC,CAAC,IAAI,CAAC,AACjC,CAAC,AAED,QAAQ,MAAM,cAAC,CAAC,AACd,KAAK,CAAE,CAAC,CACR,GAAG,CAAE,GAAG,CACR,SAAS,CAAE,UAAU,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,AAClE,CAAC,AAED,QAAQ,oBAAM,MAAM,AAAC,CAAC,AACpB,YAAY,CAAE,WAAW,CAAC,IAAI,0BAA0B,CAAC,CAAC,WAAW,CAAC,WAAW,CACjF,IAAI,CAAE,CAAC,CACP,GAAG,CAAE,GAAG,CACR,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,IAAI,CAAC,AAClC,CAAC,AAQD,QAAQ,eAAe,cAAC,CAAC,AACvB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,AACvC,CAAC,AAED,QAAQ,eAAe,KAAK,cAAC,CAAC,AAC5B,OAAO,CAAE,CAAC,AACZ,CAAC,AAID,QAAQ,IAAI,gBAAgB,cAAC,CAAC,AAC5B,UAAU,CAAE,IAAI,CAChB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,AACjE,CAAC,AAED,QAAQ,IAAI,gBAAgB,KAAK,cAAC,CAAC,AACjC,UAAU,CAAE,CAAC,CACb,OAAO,CAAE,CAAC,AACZ,CAAC,AAED,QAAQ,OAAO,gBAAgB,cAAC,CAAC,AAC/B,aAAa,CAAE,IAAI,CACnB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,AACjE,CAAC,AAED,QAAQ,OAAO,gBAAgB,KAAK,cAAC,CAAC,AACpC,aAAa,CAAE,CAAC,CAChB,OAAO,CAAE,CAAC,AACZ,CAAC,AAED,QAAQ,MAAM,gBAAgB,cAAC,CAAC,AAC9B,YAAY,CAAE,IAAI,CAClB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,AACjE,CAAC,AAED,QAAQ,MAAM,gBAAgB,KAAK,cAAC,CAAC,AACnC,YAAY,CAAE,CAAC,CACf,OAAO,CAAE,CAAC,AACZ,CAAC,AAED,QAAQ,KAAK,gBAAgB,cAAC,CAAC,AAC7B,WAAW,CAAE,IAAI,CACjB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,AACjE,CAAC,AAED,QAAQ,KAAK,gBAAgB,KAAK,cAAC,CAAC,AAClC,WAAW,CAAE,CAAC,CACd,OAAO,CAAE,CAAC,AACZ,CAAC,AAID,QAAQ,KAAK,eAAe,cAAC,CAAC,AAC5B,MAAM,CAAE,KAAK,GAAG,CAAC,CACjB,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,CAC7E,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,WAAW,AAC9F,CAAC,AAED,QAAQ,KAAK,eAAe,KAAK,cAAC,CAAC,AACjC,MAAM,CAAE,KAAK,CAAC,CAAC,CACf,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,AAC/E,CAAC,AAED,QAAQ,MAAM,eAAe,cAAC,CAAC,AAC7B,MAAM,CAAE,KAAK,GAAG,CAAC,CACjB,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,CAC5E,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,WAAW,AAC9F,CAAC,AAED,QAAQ,MAAM,eAAe,KAAK,cAAC,CAAC,AAClC,MAAM,CAAE,KAAK,CAAC,CAAC,CACf,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,AAC9E,CAAC,AAED,QAAQ,IAAI,eAAe,cAAC,CAAC,AAC3B,MAAM,CAAE,KAAK,GAAG,CAAC,CACjB,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,CAC7E,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,WAAW,AAC9F,CAAC,AAED,QAAQ,IAAI,eAAe,KAAK,cAAC,CAAC,AAChC,MAAM,CAAE,KAAK,CAAC,CAAC,CACf,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,AAC/E,CAAC,AAED,QAAQ,OAAO,eAAe,cAAC,CAAC,AAC9B,MAAM,CAAE,KAAK,GAAG,CAAC,CACjB,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,CAC5E,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,WAAW,AAC9F,CAAC,AAED,QAAQ,OAAO,eAAe,KAAK,cAAC,CAAC,AACnC,MAAM,CAAE,KAAK,CAAC,CAAC,CACf,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,AAC9E,CAAC,AAID,QAAQ,KAAK,iBAAiB,cAAC,CAAC,AAC9B,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,CAAC,MAAM,GAAG,CAAC,CAAC,GAAG,CAAC,CACjF,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,aAAa,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CAAC,AACtF,CAAC,AAED,QAAQ,KAAK,iBAAiB,KAAK,cAAC,CAAC,AACnC,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,AAC/E,CAAC,AAED,QAAQ,MAAM,iBAAiB,cAAC,CAAC,AAC/B,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,CAAC,MAAM,GAAG,CAAC,CAAC,GAAG,CAAC,CAChF,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,aAAa,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CAAC,AACtF,CAAC,AAED,QAAQ,MAAM,iBAAiB,KAAK,cAAC,CAAC,AACpC,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,IAAI,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,AAC9E,CAAC,AAED,QAAQ,IAAI,iBAAiB,cAAC,CAAC,AAC7B,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,MAAM,GAAG,CAAC,CAAC,GAAG,CAAC,CACjF,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,aAAa,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CAAC,AACtF,CAAC,AAED,QAAQ,IAAI,iBAAiB,KAAK,cAAC,CAAC,AAClC,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,AAC/E,CAAC,AAED,QAAQ,OAAO,iBAAiB,cAAC,CAAC,AAChC,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,MAAM,GAAG,CAAC,CAAC,GAAG,CAAC,CAChF,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,aAAa,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CAAC,AACtF,CAAC,AAED,QAAQ,OAAO,iBAAiB,KAAK,cAAC,CAAC,AACrC,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,AAC9E,CAAC\"}"
    };
    const Action_tooltip = create_ssr_component(($$result, $$props, $$bindings, slots) => {
      let isComponent;
      let {
        content = ''
      } = $$props;
      let {
        align = 'left'
      } = $$props;
      let {
        position = 'top'
      } = $$props;
      let {
        maxWidth = 200
      } = $$props;
      let {
        style = null
      } = $$props;
      let {
        theme = ''
      } = $$props;
      let {
        animation = ''
      } = $$props;
      let {
        arrow = true
      } = $$props;
      let {
        autoPosition = false
      } = $$props;
      let ref = null;
      let minWidth = 0;
      let animationEffect = null;
      let show = false;
      onMount(() => {
        const delay = animation ? 200 : 0;

        if (autoPosition && !isInViewport(ref)) {
          position = inverse[position];
        }

        if (animation) {
          animationEffect = animation;
        }

        setTimeout(() => show = true, delay);
      });
      onDestroy(() => {
      });
      if ($$props.content === void 0 && $$bindings.content && content !== void 0) $$bindings.content(content);
      if ($$props.align === void 0 && $$bindings.align && align !== void 0) $$bindings.align(align);
      if ($$props.position === void 0 && $$bindings.position && position !== void 0) $$bindings.position(position);
      if ($$props.maxWidth === void 0 && $$bindings.maxWidth && maxWidth !== void 0) $$bindings.maxWidth(maxWidth);
      if ($$props.style === void 0 && $$bindings.style && style !== void 0) $$bindings.style(style);
      if ($$props.theme === void 0 && $$bindings.theme && theme !== void 0) $$bindings.theme(theme);
      if ($$props.animation === void 0 && $$bindings.animation && animation !== void 0) $$bindings.animation(animation);
      if ($$props.arrow === void 0 && $$bindings.arrow && arrow !== void 0) $$bindings.arrow(arrow);
      if ($$props.autoPosition === void 0 && $$bindings.autoPosition && autoPosition !== void 0) $$bindings.autoPosition(autoPosition);
      $$result.css.add(css);
      isComponent = typeof content === 'object';
      return "<div class=\"".concat(["tooltip animation-" + escape(animationEffect, true) + " " + escape(position, true) + " " + escape(theme, true) + " svelte-oe317f", (show ? "show" : "") + ' ' + (!arrow ? "arrowless" : "")].join(' ').trim(), "\" style=\"").concat("min-width: " + escape(minWidth, true) + "px; max-width: " + escape(maxWidth, true) + "px; text-align: " + escape(align, true) + ";", "\"").concat(add_attribute("this", ref, 0), ">").concat(!isComponent ? "".concat(content) : "", "\n</div>");
    });
    var Tooltip = Action_tooltip;

    const tooltip = (element, props) => {
      let component = null;
      let title = element.getAttribute('title');

      if (title) {
        element.removeAttribute('title');
        props = {
          content: title,
          ...props
        };
      }

      const onMouseEnter = () => {
        if (!component) {
          component = new Tooltip({
            target: element,
            props
          });
        }
      };

      const onMouseLeave = () => {
        if (component) {
          component.$destroy();
          component = null;
        }
      };

      element.addEventListener('mouseenter', onMouseEnter);
      element.addEventListener('mouseleave', onMouseLeave);
      element.style.position = 'relative';
      return {
        destroy() {
          element.removeEventListener('mouseenter', onMouseEnter);
          element.removeEventListener('mouseleave', onMouseLeave);

          if (title) {
            element.setAttribute('title', title);
          }
        }

      };
    };

    exports.Tooltip = Tooltip$2;
    exports.tooltip = tooltip;

    Object.defineProperty(exports, '__esModule', { value: true });

}));
